
mustaching |version| Documentation
=======================================

.. toctree::
   :maxdepth: 2

   introduction
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

